@@ -9,7 +9,7 @@
 //! Add this to your `Cargo.toml`:
 //! ```text
 //! [dependencies]
-//! parsercher = "2.1.0"
+//! parsercher = "3.0.0"
 //! ```
 //!
 //! # Examples
@@ -37,7 +37,7 @@
 //! "#;
 //!
 //! if let Ok(root_dom) = parsercher::parse(&html) {
-//!     let mut needle = Tag::new("li".to_string());
+//!     let mut needle = Tag::new("li");
 //!     needle.set_attr("class", "target");
 //!
 //!     if let Some(texts) = parsercher::search_text_from_tag_children(&root_dom, &needle) {
@@ -497,7 +497,7 @@ mod searcher;
 pub use parser::parse;
 pub use parser::print_dom_tree;
 
-pub use dom::tag::satisfy_sufficient_condition;
+pub use searcher::search_attr;
 pub use searcher::search_dom;
 pub use searcher::search_tag;
 pub use searcher::search_tag_from_name;
